import * as gcp from '@cdktf/provider-google';
import { Construct, ConstructOptions } from 'constructs';
import { DockerVolumes } from './gitlab-runner-interfaces';
/**
 * @stability stable
 */
export interface GitlabRunnerAutoscalingProps extends ConstructOptions {
    /**
     * Google Cloud Provider.
     *
     * @stability stable
     */
    readonly provider: gcp.GoogleProvider;
    /**
     * Gitlab token.
     *
     * @stability stable
     * @example
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN' });
     */
    readonly gitlabToken: string;
    /**
     * Image URL of Gitlab Runner.
     *
     * @default public.ecr.aws/gitlab/gitlab-runner:alpine
     * @stability stable
     * @example
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', gitlabRunnerImage: 'gitlab/gitlab-runner:alpine' });
     */
    readonly gitlabRunnerImage?: string;
    /**
     * Runner default EC2 instance type.
     *
     * @default -
     * @stability stable
     * @example
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', instanceType: 't3.small' });
     */
    readonly machineType?: string;
    /**
     * VPC for the Gitlab Runner .
     *
     * @default - A new VPC will be created.
     * @stability stable
     * @example
     *
     * const newVpc = new Vpc(stack, 'NewVPC', {
     *   cidr: '10.1.0.0/16',
     *   maxAzs: 2,
     *   subnetConfiguration: [{
     *     cidrMask: 26,
     *     name: 'RunnerVPC',
     *     subnetType: SubnetType.PUBLIC,
     *   }],
     *   natGateways: 0,
     * });
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', vpc: newVpc });
     */
    readonly computeNetwork?: gcp.DataGoogleComputeNetwork;
    /**
     * Minimum capacity limit for autoscaling group.
     *
     * @default - minCapacity: 1
     * @stability stable
     * @example
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', minCapacity: 2 });
     */
    readonly minCapacity?: number;
    /**
     * Maximum capacity limit for autoscaling group.
     *
     * @default - desiredCapacity
     * @stability stable
     * @example
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', maxCapacity: 4 });
     */
    readonly maxCapacity?: number;
    /**
     * Desired capacity limit for autoscaling group.
     *
     * @default - minCapacity, and leave unchanged during deployment
     * @stability stable
     * @example
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', desiredCapacity: 2 });
     */
    readonly desiredCapacity?: number;
    /**
     * tags for the runner.
     *
     * @default - ['runner', 'gitlab', 'awscdk']
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * Gitlab Runner register url .
     *
     * @default - https://gitlab.com/ , The trailing slash is mandatory.
     * @stability stable
     * @example
     *
     * const runner = new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN',gitlabUrl: 'https://gitlab.com/'});
     */
    readonly gitlabUrl?: string;
    /**
     * Gitlab Runner instance EBS size .
     *
     * @default - ebsSize=60
     * @stability stable
     * @example
     *
     * const runner = new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', ebsSize: 100});
     */
    readonly ebsSize?: number;
    /**
     * add another Gitlab Container Runner Docker Volumes Path at job runner runtime.
     *
     * more detail see https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section
     *
     * @default - already mount "/var/run/docker.sock:/var/run/docker.sock"
     * @stability stable
     * @example
     *
     * dockerVolumes: [
     *   {
     *     hostPath: '/tmp/cache',
     *     containerPath: '/tmp/cache',
     *   },
     * ],
     */
    readonly dockerVolumes?: DockerVolumes[];
    /**
     * Gitlab Runner instance Disk size.
     *
     * @default - 60 GB.
     * @stability stable
     */
    readonly defaultDiskSizeGb?: number;
    /**
     * @stability stable
     */
    readonly serviceAccount?: gcp.ComputeInstanceTemplateServiceAccount;
    /**
     * Firewall rules for the Gitlab Runner.
     *
     * @stability stable
     */
    readonly networkTags?: string[];
}
/**
 * @stability stable
 */
export declare class GitlabRunnerAutoscaling extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: GitlabRunnerAutoscalingProps);
    private dockerVolumesList;
    /**
     * @returns Array.
     * @stability stable
     */
    createMetadataStartupScript(props: GitlabRunnerAutoscalingProps): string[];
    private createShutdwonScript;
}
